package com.ruoyi.manage.mapper;

import java.util.List;
import com.ruoyi.manage.domain.RecordWasteOut;
import org.springframework.stereotype.Repository;
/**
 * 废品处理出库Mapper接口
 *
 * @author wangh
 * @date 2024-02-21
 */
@Repository
public interface RecordWasteOutMapper
{
    /**
     * 查询废品处理出库
     *
     * @param objid 废品处理出库主键
     * @return 废品处理出库
     */
    public RecordWasteOut selectRecordWasteOutByObjid(Long objid);

    /**
     * 查询废品处理出库列表
     *
     * @param recordWasteOut 废品处理出库
     * @return 废品处理出库集合
     */
    public List<RecordWasteOut> selectRecordWasteOutList(RecordWasteOut recordWasteOut);

    /**
     * 新增废品处理出库
     *
     * @param recordWasteOut 废品处理出库
     * @return 结果
     */
    public int insertRecordWasteOut(RecordWasteOut recordWasteOut);

    /**
     * 修改废品处理出库
     *
     * @param recordWasteOut 废品处理出库
     * @return 结果
     */
    public int updateRecordWasteOut(RecordWasteOut recordWasteOut);

    /**
     * 删除废品处理出库
     *
     * @param objid 废品处理出库主键
     * @return 结果
     */
    public int deleteRecordWasteOutByObjid(Long objid);

    /**
     * 批量删除废品处理出库
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordWasteOutByObjids(String[] objids);
}
